# -*- coding: utf-8 -*-
from setuphelpers import *
import os
import sys

libdev_dir = os.sep.join([sys.executable.rsplit(os.path.sep, 1)[0].replace("/bin", ""), "libdev"])
libdev_sp_dir = os.sep.join([sys.executable.rsplit(os.path.sep, 1)[0].replace("/bin", ""), "libdev", "site-packages"])
sys.path.insert(0, libdev_dir)
sys.path.insert(0, libdev_sp_dir)


package_name = "wheel"
install_in_libdev = False  # False with lib generating bins and if any dependencies are present in "lib", then remove them from requirements.txt


def install():
    bin_name = glob.glob(f"{package_name}/{package_name}-*.whl")[0]
    for lib_dir in glob.glob(f"{libdev_sp_dir}/{package_name}*/"):
        remove_tree(lib_dir)
    if install_in_libdev:
        mkdirs(libdev_sp_dir)
        unzip(bin_name, libdev_sp_dir)
    else:
        if get_os_name() == "Windows":
            lib_sp_dir = os.sep.join([sys.executable.rsplit(os.path.sep, 1)[0], "lib", "site-packages"])
        else:
            lib_sp_dir = os.sep.join([sys.executable.rsplit(os.path.sep, 1)[0].replace("/bin", "/lib/python3.8/"), "site-packages"])
        for lib_dir in glob.glob(f"{lib_sp_dir}/{package_name}*/"):
            remove_tree(lib_dir)
        unzip(bin_name, lib_sp_dir)


def audit():
    audit_status = "OK"
    audit_pip_package = str(run(f'"{get_waptpython_path()}" -m pip show {package_name}', accept_returncodes=[0, 1, 3010]))
    print(audit_pip_package)
    if "not found" in audit_pip_package and WAPT.is_installed(control.package.split("-", 1)[0] + "-waptpython-pip"):
        print(f"Reinstalling: {control.package}")
        WAPT.install(control.package, force=True)
        audit_status = "WARNING"
    return audit_status


def uninstall():
    for lib_dir in glob.glob(f"{libdev_sp_dir}/{package_name}*/"):
        remove_tree(lib_dir)


def get_waptpython_path():
    if get_os_name() == "Windows":
        return makepath(WAPT.wapt_base_dir, "waptpython.exe")
    else:
        return makepath(WAPT.wapt_base_dir, "waptpython.sh")
